@@ -21,12 +21,12 @@ package org.apache.tez.hadoop.shim;
 import org.apache.hadoop.classification.InterfaceAudience.Private;
 
 @Private
-public class HadoopShim23_24Provider extends HadoopShimProvider {
+public class HadoopShim25_26_27Provider extends HadoopShimProvider {
 
   @Override
   public HadoopShim createHadoopShim(String hadoopVersion, int majorVersion, int minorVersion) {
-    if (majorVersion == 2 && (minorVersion == 3 || minorVersion == 4)) {
-      return new org.apache.tez.hadoop.shim.HadoopShim24();
+    if (majorVersion == 2 && (minorVersion == 5 || minorVersion == 6 || minorVersion == 7)) {
+      return new HadoopShim27();
     }
     return null;
   }
