@@ -14,6 +14,7 @@
 
 package org.apache.tez.serviceplugins.api;
 
+import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.security.Credentials;
 
 import java.util.BitSet;
@@ -41,4 +42,6 @@ public interface DagInfo {
   int getTotalVertices();
 
   BitSet getVertexDescendants(int vertexIndex);
+
+  Configuration getConf();
 }
