@@ -5,9 +5,9 @@
  * licenses this file to you under the Apache License, Version 2.0 (the
  * "License"); you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
- * 
+ *
  * http://www.apache.org/licenses/LICENSE-2.0
- * 
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
  * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
@@ -24,7 +24,7 @@ import java.io.IOException;
 import java.lang.management.ManagementFactory;
 import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
-import java.nio.charset.Charset;
+import java.nio.charset.StandardCharsets;
 import java.util.BitSet;
 import java.util.HashSet;
 import java.util.List;
@@ -47,6 +47,7 @@ import org.apache.hadoop.security.SecurityUtil;
 import org.apache.hadoop.util.StringUtils;
 import org.apache.hadoop.yarn.api.records.ApplicationId;
 import org.apache.log4j.Appender;
+import org.apache.log4j.PatternLayout;
 import org.apache.tez.common.io.NonSyncByteArrayOutputStream;
 import org.apache.tez.dag.api.DagTypeConverters;
 import org.apache.tez.dag.records.TezDAGID;
@@ -66,10 +67,12 @@ import org.slf4j.LoggerFactory;
 import org.apache.tez.dag.records.TaskAttemptTerminationCause;
 
 @Private
-public class TezUtilsInternal {
+public final class TezUtilsInternal {
 
   private static final Logger LOG = LoggerFactory.getLogger(TezUtilsInternal.class);
 
+  private TezUtilsInternal() {}
+
   public static ConfigurationProto readUserSpecifiedTezConfiguration(String baseDir) throws
       IOException {
     File confPBFile = new File(baseDir, TezConstants.TEZ_PB_BINARY_CONF_NAME);
@@ -87,7 +90,7 @@ public class TezUtilsInternal {
     }
   }
 
-  public static byte[] compressBytes(byte[] inBytes) throws IOException {
+  public static byte[] compressBytes(byte[] inBytes) {
     StopWatch sw = new StopWatch().start();
     byte[] compressed = compressBytesInflateDeflate(inBytes);
     sw.stop();
@@ -119,8 +122,7 @@ public class TezUtilsInternal {
       int count = deflater.deflate(buffer);
       bos.write(buffer, 0, count);
     }
-    byte[] output = bos.toByteArray();
-    return output;
+    return bos.toByteArray();
   }
 
   private static byte[] uncompressBytesInflateDeflate(byte[] inBytes) throws IOException {
@@ -137,8 +139,7 @@ public class TezUtilsInternal {
       }
       bos.write(buffer, 0, count);
     }
-    byte[] output = bos.toByteArray();
-    return output;
+    return bos.toByteArray();
   }
 
   private static final Pattern pattern = Pattern.compile("\\W");
@@ -153,21 +154,27 @@ public class TezUtilsInternal {
 
   private static String sanitizeString(String srcString) {
     Matcher matcher = pattern.matcher(srcString);
-    String res = matcher.replaceAll("_");
-    return res; // Number starts allowed rightnow
+    return matcher.replaceAll("_"); // Number starts allowed rightnow
   }
 
-  public static void updateLoggers(String addend) throws FileNotFoundException {
+  public static void updateLoggers(Configuration configuration, String addend, String patternString)
+      throws FileNotFoundException {
 
     LOG.info("Redirecting log file based on addend: " + addend);
 
-    Appender appender = org.apache.log4j.Logger.getRootLogger().getAppender(
-        TezConstants.TEZ_CONTAINER_LOGGER_NAME);
+    Appender appender =
+        org.apache.log4j.Logger.getRootLogger().getAppender(TezConstants.TEZ_CONTAINER_LOGGER_NAME);
     if (appender != null) {
       if (appender instanceof TezContainerLogAppender) {
         TezContainerLogAppender claAppender = (TezContainerLogAppender) appender;
         claAppender.setLogFileName(constructLogFileName(
-            TezConstants.TEZ_CONTAINER_LOG_FILE_NAME, addend));
+                addend));
+
+        // there was a configured pattern
+        if (patternString != null) {
+          PatternLayout layout = (PatternLayout) claAppender.getLayout();
+          layout.setConversionPattern(patternString);
+        }
         claAppender.activateOptions();
       } else {
         LOG.warn("Appender is a " + appender.getClass() + "; require an instance of "
@@ -179,11 +186,11 @@ public class TezUtilsInternal {
     }
   }
 
-  private static String constructLogFileName(String base, String addend) {
+  private static String constructLogFileName(String addend) {
     if (addend == null || addend.isEmpty()) {
-      return base;
+      return TezConstants.TEZ_CONTAINER_LOG_FILE_NAME;
     } else {
-      return base + "_" + addend;
+      return TezConstants.TEZ_CONTAINER_LOG_FILE_NAME + "_" + addend;
     }
   }
 
@@ -214,9 +221,8 @@ public class TezUtilsInternal {
   }
 
   /**
-   * Convert DAGPlan to text. Skip sensitive informations like credentials.
+   * Convert DAGPlan to text. Skip sensitive information like credentials.
    *
-   * @param dagPlan
    * @return a string representation of the dag plan with sensitive information removed
    */
   public static String convertDagPlanToString(DAGProtos.DAGPlan dagPlan) throws IOException {
@@ -229,7 +235,7 @@ public class TezUtilsInternal {
             DagTypeConverters.convertByteStringToCredentials(dagPlan.getCredentialsBinary());
         TextFormat.printField(entry.getKey(),
             ByteString.copyFrom(TezCommonUtils.getCredentialsInfo(credentials,"dag").getBytes(
-                Charset.forName("UTF-8"))), sb);
+                    StandardCharsets.UTF_8)), sb);
       }
     }
     return sb.toString();
@@ -257,8 +263,6 @@ public class TezUtilsInternal {
         return TaskAttemptTerminationCause.NODE_FAILED;
       case CONTAINER_EXITED:
         return TaskAttemptTerminationCause.CONTAINER_EXITED;
-      case OTHER:
-        return TaskAttemptTerminationCause.UNKNOWN_ERROR;
       default:
         return TaskAttemptTerminationCause.UNKNOWN_ERROR;
     }
