@@ -21,13 +21,16 @@ package org.apache.tez.dag.records;
 import java.io.DataInput;
 import java.io.DataOutput;
 import java.io.IOException;
+import java.util.Objects;
 
 import org.apache.hadoop.classification.InterfaceAudience;
 import org.apache.hadoop.classification.InterfaceStability;
 
-import org.apache.tez.common.Preconditions;
 import org.apache.tez.util.FastNumberFormat;
 
+import com.google.common.collect.Interner;
+import com.google.common.collect.Interners;
+
 /**
  * TaskID represents the immutable and unique identifier for
  * a Tez Task. Each TaskID encompasses multiple attempts made to
@@ -38,7 +41,7 @@ import org.apache.tez.util.FastNumberFormat;
  */
 @InterfaceAudience.Public
 @InterfaceStability.Stable
-public class TezTaskID extends TezID {
+public class TezTaskID extends TezID implements VertexIDAware {
   public static final String TASK = "task";
   private final int serializingHash;
   
@@ -51,27 +54,22 @@ public class TezTaskID extends TezID {
     }
   };
 
-  private static TezIDCache<TezTaskID> tezTaskIDCache = new TezIDCache<>();
+  private static Interner<TezTaskID> tezTaskIDCache = Interners.newWeakInterner();
   private TezVertexID vertexId;
 
   /**
    * Constructs a TezTaskID object from given {@link TezVertexID}.
    * @param vertexID the vertexID object for this TezTaskID
    * @param id the tip number
+   * @throws NullPointerException if {@code vertexID} is {@code null}
    */
   public static TezTaskID getInstance(TezVertexID vertexID, int id) {
-    Preconditions.checkArgument(vertexID != null, "vertexID cannot be null");
-    return tezTaskIDCache.getInstance(new TezTaskID(vertexID, id));
-  }
-
-  @InterfaceAudience.Private
-  public static void clearCache() {
-    tezTaskIDCache.clear();
+    Objects.requireNonNull(vertexID, "vertexID cannot be null");
+    return tezTaskIDCache.intern(new TezTaskID(vertexID, id));
   }
 
   private TezTaskID(TezVertexID vertexID, int id) {
     super(id);
-    Preconditions.checkArgument(vertexID != null, "vertexID cannot be null");
     this.vertexId = vertexID;
     this.serializingHash = getHashCode(true);
   }
@@ -81,6 +79,7 @@ public class TezTaskID extends TezID {
   }
 
   /** Returns the {@link TezVertexID} object that this task belongs to */
+  @Override
   public TezVertexID getVertexID() {
     return vertexId;
   }
