@@ -65,7 +65,7 @@ import org.apache.tez.runtime.api.impl.TezEvent;
 import org.apache.tez.runtime.api.impl.EventMetaData.EventProducerConsumerType;
 
 import com.google.common.annotations.VisibleForTesting;
-import com.google.common.base.Preconditions;
+import org.apache.tez.common.Preconditions;
 import com.google.common.collect.Maps;
 
 public class Edge {
@@ -374,7 +374,7 @@ public class Edge {
     if (!bufferEvents.get()) {
       switch (tezEvent.getEventType()) {
       case INPUT_READ_ERROR_EVENT:
-        InputReadErrorEvent event = (InputReadErrorEvent) tezEvent.getEvent();
+        InputReadErrorEvent inputReadErrorEvent = (InputReadErrorEvent) tezEvent.getEvent();
         TezTaskAttemptID destAttemptId = tezEvent.getSourceInfo()
             .getTaskAttemptID();
         int destTaskIndex = destAttemptId.getTaskID().getId();
@@ -383,10 +383,10 @@ public class Edge {
         try {
           if (onDemandRouting) {
             srcTaskIndex = ((EdgeManagerPluginOnDemand) edgeManager).routeInputErrorEventToSource(
-                destTaskIndex, event.getIndex());            
+                destTaskIndex, inputReadErrorEvent.getIndex());
           } else {
-            srcTaskIndex = edgeManager.routeInputErrorEventToSource(event,
-                destTaskIndex, event.getIndex());
+            srcTaskIndex = edgeManager.routeInputErrorEventToSource(inputReadErrorEvent,
+                destTaskIndex, inputReadErrorEvent.getIndex());
           }
           Preconditions.checkArgument(srcTaskIndex >= 0,
               "SourceTaskIndex should not be negative,"
@@ -413,12 +413,11 @@ public class Edge {
               " destIndex=" + destTaskIndex + 
               " edgeManager=" + edgeManager.getClass().getName());
         }
-        TezTaskID srcTaskId = srcTask.getTaskId();
-        int taskAttemptIndex = event.getVersion();
+        TezTaskID srcTaskId = srcTask.getTaskID();
+        int srcTaskAttemptIndex = inputReadErrorEvent.getVersion();
         TezTaskAttemptID srcTaskAttemptId = TezTaskAttemptID.getInstance(srcTaskId,
-            taskAttemptIndex);
-        sendEvent(new TaskAttemptEventOutputFailed(srcTaskAttemptId,
-            tezEvent, numConsumers));
+            srcTaskAttemptIndex);
+        sendEvent(new TaskAttemptEventOutputFailed(srcTaskAttemptId, tezEvent, numConsumers));
         break;
       default:
         throw new TezUncheckedException("Unhandled tez event type: "
