@@ -102,6 +102,11 @@ public class TezRootInputInitializerContextImpl implements
     return vertex.getTaskResource();
   }
 
+  @Override
+  public int getVertexId() {
+    return vertex.getVertexId().getId();
+  }
+
   @Override
   public Resource getTotalAvailableResource() {
     return appContext.getTaskScheduler().getTotalResources(vertex.getTaskSchedulerIdentifier());
