@@ -642,7 +642,7 @@ public class YarnTaskSchedulerService extends TaskScheduler
       long currentTime = System.currentTimeMillis();
       boolean releaseContainer = false;
 
-      if (isNew || (heldContainer.getContainerExpiryTime() <= currentTime
+      if (isNew || (heldContainer.getContainerExpiryTime() - currentTime <= 0
           && idleContainerTimeoutMin != -1)) {
         // container idle timeout has expired or is a new unused container. 
         // new container is possibly a spurious race condition allocation.
@@ -775,7 +775,7 @@ public class YarnTaskSchedulerService extends TaskScheduler
         // if we are not being able to assign containers to pending tasks then 
         // we cannot avoid releasing containers. Or else we may not be able to 
         // get new containers from YARN to match the pending request
-        if (!isNew && heldContainer.getContainerExpiryTime() <= currentTime
+        if (!isNew && heldContainer.getContainerExpiryTime() - currentTime <= 0
           && idleContainerTimeoutMin != -1) {
           LOG.info("Container's idle timeout expired. Releasing container"
               + ", containerId=" + heldContainer.container.getId()
@@ -1275,7 +1275,7 @@ public class YarnTaskSchedulerService extends TaskScheduler
             + numHighestPriRequests + " pending requests at pri: "
             + highestPriRequest.getPriority());
       }
-
+      int newContainersReleased = 0;
       for (int i=0; i<numPendingRequestsToService; ++i) {
         // This request must have been considered for matching with all existing 
         // containers when request was made.
@@ -1311,7 +1311,7 @@ public class YarnTaskSchedulerService extends TaskScheduler
               " with priority: " + lowestPriNewContainer.getPriority() + 
               " to free resource for request: " + highestPriRequest +
               " . Current free resources: " + freeResources);
-          numPendingRequestsToService--;
+          newContainersReleased++;
           releaseUnassignedContainers(Collections.singletonList(lowestPriNewContainer));
           // We are returning an unused resource back the RM. The RM thinks it 
           // has serviced our initial request and will not re-allocate this back
@@ -1324,7 +1324,7 @@ public class YarnTaskSchedulerService extends TaskScheduler
           continue;
         }
       }
-      
+      numPendingRequestsToService -= newContainersReleased;
       if (numPendingRequestsToService < 1) {
         return true;
       }
@@ -1573,6 +1573,9 @@ public class YarnTaskSchedulerService extends TaskScheduler
     if (delayedContainer != null) {
       Resources.subtractFrom(allocatedResources,
           delayedContainer.getContainer().getResource());
+      if (shouldReuseContainers) {
+        delayedContainerManager.removeDelayedContainer(delayedContainer);
+      }
     }
     if (delayedContainer != null || !shouldReuseContainers) {
       amRmClient.releaseAssignedContainer(containerId);
@@ -2025,7 +2028,7 @@ public class YarnTaskSchedulerService extends TaskScheduler
         LOG.debug("Considering HeldContainer: {} for assignment", delayedContainer);
         long currentTs = System.currentTimeMillis();
         long nextScheduleTs = delayedContainer.getNextScheduleTime();
-        if (currentTs >= nextScheduleTs) {
+        if (currentTs - nextScheduleTs >= 0) {
           Map<CookieContainerRequest, Container> assignedContainers = null;
           synchronized(YarnTaskSchedulerService.this) {
             // Remove the container and try scheduling it.
@@ -2163,6 +2166,13 @@ public class YarnTaskSchedulerService extends TaskScheduler
       }
     }
 
+    void removeDelayedContainer(HeldContainer container) {
+      synchronized(this) {
+        if (delayedContainers.remove(container)) {
+          LOG.debug("Removed {} from delayed containers", container.getContainer().getId());
+        }
+      }
+    }
   }
   
   synchronized void determineMinHeldContainers() {
