@@ -153,9 +153,7 @@ public class TestSpeculation {
                     .contains(UNIT_EXCEPTION_MESSAGE)))) {
                   throw caughtThrowable;
                 }
-                LOG.warn("{} : Failed. Retries remaining: ",
-                    description.getDisplayName(),
-                    retryCount.toString());
+                LOG.warn("{} : Failed. Retries remaining: {}", description.getDisplayName(), retryCount.toString());
               } else {
                 throw caughtThrowable;
               }
@@ -300,7 +298,7 @@ public class TestSpeculation {
               TezConfiguration.TEZ_AM_LEGACY_SPECULATIVE_SINGLE_TASK_VERTEX_TIMEOUT,
               entry.getKey());
 
-      DAG dag = DAG.create("test");
+      DAG dag = DAG.create("DAG-testSingleTaskSpeculation");
       Vertex vA = Vertex.create("A",
               ProcessorDescriptor.create("Proc.class"),
               1);
@@ -343,7 +341,7 @@ public class TestSpeculation {
    * @throws Exception the exception
    */
   public void testBasicSpeculation(boolean withProgress) throws Exception {
-    DAG dag = DAG.create("test");
+    DAG dag = DAG.create("DAG-testBasicSpeculation");
     Vertex vA = Vertex.create("A",
         ProcessorDescriptor.create("Proc.class"), 5);
     dag.addVertex(vA);
@@ -426,7 +424,7 @@ public class TestSpeculation {
   @Retry
   @Test (timeout=30000)
   public void testBasicSpeculationPerVertexConf() throws Exception {
-    DAG dag = DAG.create("test");
+    DAG dag = DAG.create("DAG-testBasicSpeculationPerVertexConf");
     String vNameNoSpec = "A";
     String vNameSpec = "B";
     Vertex vA = Vertex.create(vNameNoSpec, ProcessorDescriptor.create("Proc.class"), 5);
@@ -487,7 +485,7 @@ public class TestSpeculation {
   @Retry
   @Test (timeout=30000)
   public void testBasicSpeculationNotUseful() throws Exception {
-    DAG dag = DAG.create("test");
+    DAG dag = DAG.create("DAG-testBasicSpeculationNotUseful");
     Vertex vA = Vertex.create("A", ProcessorDescriptor.create("Proc.class"), 5);
     dag.addVertex(vA);
 
