@@ -27,7 +27,7 @@ import org.apache.tez.dag.library.vertexmanager.ShuffleVertexManager;
 import org.apache.tez.runtime.library.api.TezRuntimeConfiguration;
 import org.apache.tez.runtime.library.common.Constants;
 
-public class DeprecatedKeys {
+public final class DeprecatedKeys {
 
   
   
@@ -35,13 +35,13 @@ public class DeprecatedKeys {
   /**
    * Keys used by the DAG - mainly the AM. 
    */
-  private static Map<String, String> mrParamToDAGParamMap = new HashMap<String, String>();
+  private static final Map<String, String> MR_PARAM_TO_DAG_PARAM_MAP = new HashMap<>();
 
   /**
    * Keys used by the Tez Runtime.
    */
-  private static Map<String, String> mrParamToTezRuntimeParamMap =
-      new HashMap<String, String>();
+  private static final Map<String, String> MR_PARAM_TO_TEZ_RUNTIME_PARAM_MAP =
+          new HashMap<>();
 
   
  
@@ -51,20 +51,22 @@ public class DeprecatedKeys {
     addDeprecatedKeys();
   }
 
+  private DeprecatedKeys() {}
+
   private static void populateMRToDagParamMap() {
     // TODO Default value handling.
-    mrParamToDAGParamMap.put(MRJobConfig.MR_AM_TASK_LISTENER_THREAD_COUNT,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.MR_AM_TASK_LISTENER_THREAD_COUNT,
         TezConfiguration.TEZ_AM_TASK_LISTENER_THREAD_COUNT);
     
-    mrParamToDAGParamMap.put(MRJobConfig.MAX_TASK_FAILURES_PER_TRACKER,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.MAX_TASK_FAILURES_PER_TRACKER,
         TezConfiguration.TEZ_AM_MAX_TASK_FAILURES_PER_NODE);
-    mrParamToDAGParamMap.put(MRJobConfig.MR_AM_JOB_NODE_BLACKLISTING_ENABLE,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.MR_AM_JOB_NODE_BLACKLISTING_ENABLE,
         TezConfiguration.TEZ_AM_NODE_BLACKLISTING_ENABLED);
-    mrParamToDAGParamMap.put(
+    MR_PARAM_TO_DAG_PARAM_MAP.put(
         MRJobConfig.MR_AM_IGNORE_BLACKLISTING_BLACKLISTED_NODE_PERECENT,
         TezConfiguration.TEZ_AM_NODE_BLACKLISTING_IGNORE_THRESHOLD);
 
-    mrParamToDAGParamMap.put(MRJobConfig.QUEUE_NAME,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.QUEUE_NAME,
       TezConfiguration.TEZ_QUEUE_NAME);
 
     // Counter replacement will work in this manner, as long as TezCounters
@@ -73,23 +75,23 @@ public class DeprecatedKeys {
     // may break.
     // Framework counters, like FILESYSTEM will likely be incompatible since
     // they enum key belongs to a different package.
-    mrParamToDAGParamMap.put(MRJobConfig.COUNTERS_MAX_KEY,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.COUNTERS_MAX_KEY,
       TezConfiguration.TEZ_COUNTERS_MAX);
-    mrParamToDAGParamMap.put(MRJobConfig.COUNTER_GROUPS_MAX_KEY,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.COUNTER_GROUPS_MAX_KEY,
         TezConfiguration.TEZ_COUNTERS_MAX_GROUPS);
-    mrParamToDAGParamMap.put(MRJobConfig.COUNTER_NAME_MAX_KEY,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.COUNTER_NAME_MAX_KEY,
         TezConfiguration.TEZ_COUNTERS_COUNTER_NAME_MAX_LENGTH);
-    mrParamToDAGParamMap.put(MRJobConfig.COUNTER_GROUP_NAME_MAX_KEY,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.COUNTER_GROUP_NAME_MAX_KEY,
       TezConfiguration.TEZ_COUNTERS_GROUP_NAME_MAX_LENGTH);
-    mrParamToDAGParamMap.put(MRJobConfig.TASK_TIMEOUT,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.TASK_TIMEOUT,
         TezConfiguration.TASK_HEARTBEAT_TIMEOUT_MS);
-    mrParamToDAGParamMap.put(MRJobConfig.JOB_TAGS,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.JOB_TAGS,
         TezConfiguration.TEZ_APPLICATION_TAGS);
-    mrParamToDAGParamMap.put(MRJobConfig.MAPREDUCE_JOB_USER_CLASSPATH_FIRST,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.MAPREDUCE_JOB_USER_CLASSPATH_FIRST,
         TezConfiguration.TEZ_USER_CLASSPATH_FIRST);
-    mrParamToDAGParamMap.put(MRJobConfig.JOB_NAMENODES,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.JOB_NAMENODES,
             TezConfiguration.TEZ_JOB_FS_SERVERS);
-    mrParamToDAGParamMap.put(MRJobConfig.JOB_NAMENODES_TOKEN_RENEWAL_EXCLUDE,
+    MR_PARAM_TO_DAG_PARAM_MAP.put(MRJobConfig.JOB_NAMENODES_TOKEN_RENEWAL_EXCLUDE,
             TezConfiguration.TEZ_JOB_FS_SERVERS_TOKEN_RENEWAL_EXCLUDE);
   }
 
@@ -181,14 +183,14 @@ public class DeprecatedKeys {
 
   private static void registerMRToRuntimeKeyTranslation(String mrKey,
       String tezKey) {
-    mrParamToTezRuntimeParamMap.put(mrKey, tezKey);
+    MR_PARAM_TO_TEZ_RUNTIME_PARAM_MAP.put(mrKey, tezKey);
   }
 
   public static Map<String, String> getMRToDAGParamMap() {
-    return Collections.unmodifiableMap(mrParamToDAGParamMap);
+    return Collections.unmodifiableMap(MR_PARAM_TO_DAG_PARAM_MAP);
   }
 
   public static Map<String, String> getMRToTezRuntimeParamMap() {
-    return Collections.unmodifiableMap(mrParamToTezRuntimeParamMap);
+    return Collections.unmodifiableMap(MR_PARAM_TO_TEZ_RUNTIME_PARAM_MAP);
   }
 }
