@@ -23,6 +23,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Random;
 import java.util.Set;
+import java.util.concurrent.atomic.AtomicBoolean;
 
 import org.apache.hadoop.conf.Configuration;
 import org.apache.hadoop.yarn.api.records.ApplicationAttemptId;
@@ -31,7 +32,6 @@ import org.apache.hadoop.yarn.api.records.ContainerId;
 import org.apache.hadoop.yarn.api.records.NodeId;
 import org.apache.hadoop.yarn.api.records.timeline.TimelineEntity;
 import org.apache.hadoop.yarn.api.records.timeline.TimelineEvent;
-import org.apache.tez.client.CallerContext;
 import org.apache.tez.common.ATSConstants;
 import org.apache.tez.common.VersionInfo;
 import org.apache.tez.common.counters.TezCounters;
@@ -48,6 +48,7 @@ import org.apache.tez.dag.api.records.DAGProtos.CallerContextProto;
 import org.apache.tez.dag.api.records.DAGProtos.DAGPlan;
 import org.apache.tez.dag.app.dag.DAGState;
 import org.apache.tez.dag.app.dag.VertexState;
+import org.apache.tez.dag.app.dag.impl.ServicePluginInfo;
 import org.apache.tez.dag.app.dag.impl.TaskAttemptImpl.DataEventDependencyInfo;
 import org.apache.tez.dag.app.dag.impl.VertexStats;
 import org.apache.tez.dag.app.web.AMWebController;
@@ -83,6 +84,7 @@ import org.apache.tez.dag.records.TezDAGID;
 import org.apache.tez.dag.records.TezTaskAttemptID;
 import org.apache.tez.dag.records.TezTaskID;
 import org.apache.tez.dag.records.TezVertexID;
+import org.apache.tez.runtime.api.TaskFailureType;
 import org.codehaus.jettison.json.JSONException;
 import org.junit.Assert;
 import org.junit.Before;
@@ -143,7 +145,7 @@ public class TestHistoryEventTimelineConversion {
           break;
         case DAG_SUBMITTED:
           event = new DAGSubmittedEvent(tezDAGID, random.nextInt(), dagPlan, applicationAttemptId,
-              null, user, null, containerLogs);
+              null, user, null, containerLogs, null);
           break;
         case DAG_INITIALIZED:
           event = new DAGInitializedEvent(tezDAGID, random.nextInt(), user, dagPlan.getName(), null);
@@ -157,7 +159,7 @@ public class TestHistoryEventTimelineConversion {
           break;
         case VERTEX_INITIALIZED:
           event = new VertexInitializedEvent(tezVertexID, "v1", random.nextInt(), random.nextInt(),
-              random.nextInt(), "proc", null, null);
+              random.nextInt(), "proc", null, null, null);
           break;
         case VERTEX_STARTED:
           event = new VertexStartedEvent(tezVertexID, random.nextInt(), random.nextInt());
@@ -168,7 +170,7 @@ public class TestHistoryEventTimelineConversion {
         case VERTEX_FINISHED:
           event = new VertexFinishedEvent(tezVertexID, "v1", 1, random.nextInt(), random.nextInt(),
               random.nextInt(), random.nextInt(), random.nextInt(), VertexState.ERROR,
-              null, null, null, null);
+              null, null, null, null, null);
           break;
         case TASK_STARTED:
           event = new TaskStartedEvent(tezTaskID, "v1", random.nextInt(), random.nextInt());
@@ -183,8 +185,9 @@ public class TestHistoryEventTimelineConversion {
           break;
         case TASK_ATTEMPT_FINISHED:
           event = new TaskAttemptFinishedEvent(tezTaskAttemptID, "v1", random.nextInt(),
-              random.nextInt(), TaskAttemptState.FAILED, TaskAttemptTerminationCause.OUTPUT_LOST,
-              null, null, null, null, 0, null, 0);
+              random.nextInt(), TaskAttemptState.FAILED, TaskFailureType.NON_FATAL, TaskAttemptTerminationCause.OUTPUT_LOST,
+              null, null, null, null, 0, null, 0,
+              containerId, nodeId, null, null, "nodeHttpAddress");
           break;
         case CONTAINER_LAUNCHED:
           event = new ContainerLaunchedEvent(containerId, random.nextInt(),
@@ -218,7 +221,7 @@ public class TestHistoryEventTimelineConversion {
       if (event == null || !event.isHistoryEvent()) {
         continue;
       }
-      HistoryEventTimelineConversion.convertToTimelineEntity(event);
+      HistoryEventTimelineConversion.convertToTimelineEntities(event);
     }
   }
 
@@ -230,6 +233,39 @@ public class TestHistoryEventTimelineConversion {
 
   }
 
+  @Test(timeout = 5000)
+  public void testConvertAppLaunchedEventConcurrentModificationException()
+      throws InterruptedException {
+    long launchTime = random.nextLong();
+    long submitTime = random.nextLong();
+    final Configuration conf = new Configuration(false);
+    conf.set("foo", "bar");
+    conf.set("applicationId", "1234");
+    final AtomicBoolean shutdown = new AtomicBoolean(false);
+
+    Thread confChanger = new Thread() {
+      @Override
+      public void run() {
+        int i = 1;
+        while (!shutdown.get()) {
+          // trigger an actual change to test concurrency with Configuration#iterator
+          conf.set("test" + i++, "test");
+        }
+      }
+    };
+
+    confChanger.start();
+    try {
+      MockVersionInfo mockVersionInfo = new MockVersionInfo();
+      AppLaunchedEvent event = new AppLaunchedEvent(applicationId, launchTime,
+          submitTime, user, conf, mockVersionInfo);
+      HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    } finally {
+      shutdown.set(true);
+      confChanger.join();
+    }
+  }
+
   @SuppressWarnings("unchecked")
   @Test(timeout = 5000)
   public void testConvertAppLaunchedEvent() {
@@ -243,7 +279,9 @@ public class TestHistoryEventTimelineConversion {
     AppLaunchedEvent event = new AppLaunchedEvent(applicationId, launchTime,
         submitTime, user, conf, mockVersionInfo);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
 
     Assert.assertEquals(launchTime, timelineEntity.getStartTime().longValue());
 
@@ -286,7 +324,9 @@ public class TestHistoryEventTimelineConversion {
     long submitTime = random.nextLong();
     AMLaunchedEvent event = new AMLaunchedEvent(applicationAttemptId, launchTime, submitTime, user);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
 
     Assert.assertEquals("tez_" + applicationAttemptId.toString(), timelineEntity.getEntityId());
     Assert.assertEquals(EntityTypes.TEZ_APPLICATION_ATTEMPT.name(), timelineEntity.getEntityType());
@@ -321,7 +361,9 @@ public class TestHistoryEventTimelineConversion {
 
     AMStartedEvent event = new AMStartedEvent(applicationAttemptId, startTime, user);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
 
     Assert.assertEquals("tez_" + applicationAttemptId.toString(), timelineEntity.getEntityId());
     Assert.assertEquals(EntityTypes.TEZ_APPLICATION_ATTEMPT.name(), timelineEntity.getEntityType());
@@ -347,7 +389,9 @@ public class TestHistoryEventTimelineConversion {
     long launchTime = random.nextLong();
     ContainerLaunchedEvent event = new ContainerLaunchedEvent(containerId, launchTime,
         applicationAttemptId);
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
 
     Assert.assertEquals(EntityTypes.TEZ_CONTAINER_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals("tez_" + containerId.toString(), timelineEntity.getEntityId());
@@ -378,7 +422,9 @@ public class TestHistoryEventTimelineConversion {
     int exitStatus = random.nextInt();
     ContainerStoppedEvent event = new ContainerStoppedEvent(containerId, stopTime, exitStatus,
         applicationAttemptId);
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
 
     Assert.assertEquals("tez_" + containerId.toString(), timelineEntity.getEntityId());
     Assert.assertEquals(EntityTypes.TEZ_CONTAINER_ID.name(), timelineEntity.getEntityType());
@@ -410,7 +456,10 @@ public class TestHistoryEventTimelineConversion {
     long startTime = random.nextLong();
     String dagName = "testDagName";
     DAGStartedEvent event = new DAGStartedEvent(tezDAGID, startTime, user, dagName);
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
+
 
     Assert.assertEquals(tezDAGID.toString(), timelineEntity.getEntityId());
     Assert.assertEquals(EntityTypes.TEZ_DAG_ID.name(), timelineEntity.getEntityType());
@@ -437,10 +486,25 @@ public class TestHistoryEventTimelineConversion {
   public void testConvertDAGSubmittedEvent() {
     long submitTime = random.nextLong();
 
+    final String queueName = "TEST_DAG_SUBMITTED";
     DAGSubmittedEvent event = new DAGSubmittedEvent(tezDAGID, submitTime, dagPlan,
-        applicationAttemptId, null, user, null, containerLogs);
+        applicationAttemptId, null, user, null, containerLogs, queueName);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(2, entities.size());
+
+
+    if (entities.get(0).getEntityType().equals(EntityTypes.TEZ_DAG_ID.name())) {
+      assertDagSubmittedEntity(submitTime, event, entities.get(0));
+      assertDagSubmittedExtraInfoEntity(submitTime, event, entities.get(1));
+    } else {
+      assertDagSubmittedExtraInfoEntity(submitTime, event, entities.get(0));
+      assertDagSubmittedEntity(submitTime, event, entities.get(1));
+    }
+  }
+
+  private void assertDagSubmittedEntity(long submitTime, DAGSubmittedEvent event,
+      TimelineEntity timelineEntity) {
     Assert.assertEquals(EntityTypes.TEZ_DAG_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezDAGID.toString(), timelineEntity.getEntityId());
 
@@ -459,7 +523,7 @@ public class TestHistoryEventTimelineConversion {
 
     Assert.assertEquals(submitTime, timelineEntity.getStartTime().longValue());
 
-    Assert.assertEquals(4, timelineEntity.getPrimaryFilters().size());
+    Assert.assertEquals(5, timelineEntity.getPrimaryFilters().size());
 
     Assert.assertTrue(
         timelineEntity.getPrimaryFilters().get(ATSConstants.DAG_NAME).contains(
@@ -472,9 +536,11 @@ public class TestHistoryEventTimelineConversion {
             applicationAttemptId.getApplicationId().toString()));
     Assert.assertTrue(
         timelineEntity.getPrimaryFilters().get(ATSConstants.USER).contains(user));
+    Assert.assertTrue(
+        timelineEntity.getPrimaryFilters().get(ATSConstants.DAG_QUEUE_NAME)
+            .contains(event.getQueueName()));
 
-    Assert.assertEquals(8, timelineEntity.getOtherInfo().size());
-    Assert.assertTrue(timelineEntity.getOtherInfo().containsKey(ATSConstants.DAG_PLAN));
+    Assert.assertEquals(9, timelineEntity.getOtherInfo().size());
     Assert.assertEquals(applicationId.toString(),
         timelineEntity.getOtherInfo().get(ATSConstants.APPLICATION_ID));
     Assert.assertEquals(applicationAttemptId.toString(),
@@ -494,8 +560,31 @@ public class TestHistoryEventTimelineConversion {
     Assert.assertEquals(
         timelineEntity.getOtherInfo().get(ATSConstants.CALLER_CONTEXT_TYPE),
             dagPlan.getCallerContext().getCallerType());
+    Assert.assertEquals(dagPlan.getCallerContext().getContext(),
+        timelineEntity.getOtherInfo().get(ATSConstants.CALLER_CONTEXT));
+    Assert.assertEquals(
+        event.getQueueName(), timelineEntity.getOtherInfo().get(ATSConstants.DAG_QUEUE_NAME));
 
+  }
 
+  private void assertDagSubmittedExtraInfoEntity(long submitTime, DAGSubmittedEvent event,
+      TimelineEntity timelineEntity) {
+    Assert.assertEquals(EntityTypes.TEZ_DAG_EXTRA_INFO.name(), timelineEntity.getEntityType());
+    Assert.assertEquals(tezDAGID.toString(), timelineEntity.getEntityId());
+
+    Assert.assertEquals(1, timelineEntity.getRelatedEntities().size());
+    Assert.assertTrue(timelineEntity.getRelatedEntities()
+        .get(EntityTypes.TEZ_DAG_ID.name()).contains(tezDAGID.toString()));
+
+    Assert.assertEquals(1, timelineEntity.getEvents().size());
+    TimelineEvent timelineEvent = timelineEntity.getEvents().get(0);
+    Assert.assertEquals(HistoryEventType.DAG_SUBMITTED.name(), timelineEvent.getEventType());
+    Assert.assertEquals(submitTime, timelineEvent.getTimestamp());
+
+    Assert.assertEquals(submitTime, timelineEntity.getStartTime().longValue());
+    Assert.assertEquals(0, timelineEntity.getPrimaryFilters().size());
+    Assert.assertEquals(1, timelineEntity.getOtherInfo().size());
+    Assert.assertTrue(timelineEntity.getOtherInfo().containsKey(ATSConstants.DAG_PLAN));
   }
 
   @SuppressWarnings("unchecked")
@@ -518,9 +607,12 @@ public class TestHistoryEventTimelineConversion {
     events.add(new DataEventDependencyInfo(lastDataEventTime, tezTaskAttemptID));
 
     TaskAttemptFinishedEvent event = new TaskAttemptFinishedEvent(tezTaskAttemptID, vertexName,
-        startTime, finishTime, state, error, diagnostics, counters, events, null, creationTime,
-        tezTaskAttemptID, allocationTime);
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+        startTime, finishTime, state, TaskFailureType.FATAL, error, diagnostics, counters, events, null, creationTime,
+        tezTaskAttemptID, allocationTime, containerId, nodeId, "inProgressURL", "logsURL", "nodeHttpAddress");
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
+
     Assert.assertEquals(tezTaskAttemptID.toString(), timelineEntity.getEntityId());
     Assert.assertEquals(EntityTypes.TEZ_TASK_ATTEMPT_ID.name(), timelineEntity.getEntityType());
 
@@ -542,7 +634,7 @@ public class TestHistoryEventTimelineConversion {
     Assert.assertEquals(finishTime, evt.getTimestamp());
 
     final Map<String, Object> otherInfo = timelineEntity.getOtherInfo();
-    Assert.assertEquals(11, otherInfo.size());
+    Assert.assertEquals(17, otherInfo.size());
     Assert.assertEquals(tezTaskAttemptID.toString(), 
         timelineEntity.getOtherInfo().get(ATSConstants.CREATION_CAUSAL_ATTEMPT));
     Assert.assertEquals(creationTime, timelineEntity.getOtherInfo().get(ATSConstants.CREATION_TIME));
@@ -551,6 +643,7 @@ public class TestHistoryEventTimelineConversion {
     Assert.assertEquals(finishTime, otherInfo.get(ATSConstants.FINISH_TIME));
     Assert.assertEquals(finishTime - startTime, otherInfo.get(ATSConstants.TIME_TAKEN));
     Assert.assertEquals(state.name(), otherInfo.get(ATSConstants.STATUS));
+    Assert.assertEquals(TaskFailureType.FATAL.name(), otherInfo.get(ATSConstants.TASK_FAILURE_TYPE));
     Assert.assertEquals(error.name(), otherInfo.get(ATSConstants.TASK_ATTEMPT_ERROR_ENUM));
     Assert.assertEquals(diagnostics, otherInfo.get(ATSConstants.DIAGNOSTICS));
     Map<String, Object> obj1 = (Map<String, Object>)otherInfo.get(ATSConstants.LAST_DATA_EVENTS);
@@ -559,6 +652,25 @@ public class TestHistoryEventTimelineConversion {
     Map<String, Object> obj3 = (Map<String, Object>) obj2.get(0);
     Assert.assertEquals(events.get(0).getTimestamp(), obj3.get(ATSConstants.TIMESTAMP));
     Assert.assertTrue(otherInfo.containsKey(ATSConstants.COUNTERS));
+    Assert.assertEquals("inProgressURL", otherInfo.get(ATSConstants.IN_PROGRESS_LOGS_URL));
+    Assert.assertEquals("logsURL", otherInfo.get(ATSConstants.COMPLETED_LOGS_URL));
+    Assert.assertEquals(nodeId.toString(), otherInfo.get(ATSConstants.NODE_ID));
+    Assert.assertEquals(containerId.toString(), otherInfo.get(ATSConstants.CONTAINER_ID));
+    Assert.assertEquals("nodeHttpAddress", otherInfo.get(ATSConstants.NODE_HTTP_ADDRESS));
+
+    TaskAttemptFinishedEvent eventWithNullFailureType =
+        new TaskAttemptFinishedEvent(tezTaskAttemptID, vertexName,
+            startTime, finishTime, state, null, error, diagnostics, counters, events, null,
+            creationTime,
+            tezTaskAttemptID, allocationTime, containerId, nodeId, "inProgressURL", "logsURL",
+            "nodeHttpAddress");
+    List<TimelineEntity> evtEntities = HistoryEventTimelineConversion.convertToTimelineEntities(
+        eventWithNullFailureType);
+    Assert.assertEquals(1, evtEntities.size());
+    TimelineEntity timelineEntityWithNullFailureType = evtEntities.get(0);
+
+    Assert.assertNull(
+        timelineEntityWithNullFailureType.getOtherInfo().get(ATSConstants.TASK_FAILURE_TYPE));
   }
 
   @SuppressWarnings("unchecked")
@@ -572,7 +684,11 @@ public class TestHistoryEventTimelineConversion {
     DAGInitializedEvent event = new DAGInitializedEvent(tezDAGID, initTime, "user", "dagName",
         nameIdMap);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
+
     Assert.assertEquals(EntityTypes.TEZ_DAG_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezDAGID.toString(), timelineEntity.getEntityId());
 
@@ -613,7 +729,20 @@ public class TestHistoryEventTimelineConversion {
     DAGFinishedEvent event = new DAGFinishedEvent(tezDAGID, startTime, finishTime, DAGState.ERROR,
         "diagnostics", null, user, dagPlan.getName(), taskStats, applicationAttemptId, dagPlan);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(2, entities.size());
+
+    if (entities.get(0).getEntityType().equals(EntityTypes.TEZ_DAG_ID.name())) {
+      assertDagFinishedEntity(finishTime, startTime, event, entities.get(0));
+      assertDagFinishedExtraInfoEntity(finishTime, entities.get(1));
+    } else {
+      assertDagFinishedExtraInfoEntity(finishTime, entities.get(0));
+      assertDagFinishedEntity(finishTime, startTime, event, entities.get(1));
+    }
+  }
+
+  private void assertDagFinishedEntity(long finishTime, long startTime, DAGFinishedEvent event,
+      TimelineEntity timelineEntity) {
     Assert.assertEquals(EntityTypes.TEZ_DAG_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezDAGID.toString(), timelineEntity.getEntityId());
 
@@ -645,7 +774,6 @@ public class TestHistoryEventTimelineConversion {
         ((Long) timelineEntity.getOtherInfo().get(ATSConstants.FINISH_TIME)).longValue());
     Assert.assertEquals(finishTime - startTime,
         ((Long) timelineEntity.getOtherInfo().get(ATSConstants.TIME_TAKEN)).longValue());
-    Assert.assertTrue(timelineEntity.getOtherInfo().containsKey(ATSConstants.COUNTERS));
     Assert.assertEquals(DAGState.ERROR.name(),
         timelineEntity.getOtherInfo().get(ATSConstants.STATUS));
     Assert.assertEquals("diagnostics",
@@ -659,15 +787,42 @@ public class TestHistoryEventTimelineConversion {
         ((Integer) timelineEntity.getOtherInfo().get("BAR")).intValue());
   }
 
+  private void assertDagFinishedExtraInfoEntity(long finishTime, TimelineEntity timelineEntity) {
+    Assert.assertEquals(EntityTypes.TEZ_DAG_EXTRA_INFO.name(), timelineEntity.getEntityType());
+    Assert.assertEquals(tezDAGID.toString(), timelineEntity.getEntityId());
+
+    Assert.assertEquals(1, timelineEntity.getRelatedEntities().size());
+    Assert.assertTrue(
+        timelineEntity.getRelatedEntities().get(ATSConstants.TEZ_DAG_ID).contains(
+            tezDAGID.toString()));
+
+    Assert.assertEquals(1, timelineEntity.getEvents().size());
+    TimelineEvent timelineEvent = timelineEntity.getEvents().get(0);
+    Assert.assertEquals(HistoryEventType.DAG_FINISHED.name(), timelineEvent.getEventType());
+    Assert.assertEquals(finishTime, timelineEvent.getTimestamp());
+
+    Assert.assertTrue(timelineEntity.getOtherInfo().containsKey(ATSConstants.COUNTERS));
+  }
+
+  @SuppressWarnings("unchecked")
   @Test(timeout = 5000)
   public void testConvertVertexInitializedEvent() {
     long initRequestedTime = random.nextLong();
     long initedTime = random.nextLong();
     int numTasks = random.nextInt();
     VertexInitializedEvent event = new VertexInitializedEvent(tezVertexID, "v1", initRequestedTime,
-        initedTime, numTasks, "proc", null, null);
+        initedTime, numTasks, "proc", null, null,
+        new ServicePluginInfo().setContainerLauncherName("abc")
+            .setTaskSchedulerName("def").setTaskCommunicatorName("ghi")
+            .setContainerLauncherClassName("abc1")
+            .setTaskSchedulerClassName("def1")
+            .setTaskCommunicatorClassName("ghi1"));
+
+
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
     Assert.assertEquals(EntityTypes.TEZ_VERTEX_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezVertexID.toString(), timelineEntity.getEntityId());
 
@@ -702,6 +857,25 @@ public class TestHistoryEventTimelineConversion {
         ((Long) timelineEntity.getOtherInfo().get(ATSConstants.INIT_TIME)).longValue());
     Assert.assertEquals(numTasks,
         ((Integer) timelineEntity.getOtherInfo().get(ATSConstants.NUM_TASKS)).intValue());
+    Assert.assertNotNull(timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN));
+    Assert.assertEquals("abc",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.CONTAINER_LAUNCHER_NAME));
+    Assert.assertEquals("def",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.TASK_SCHEDULER_NAME));
+    Assert.assertEquals("ghi",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.TASK_COMMUNICATOR_NAME));
+    Assert.assertEquals("abc1",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.CONTAINER_LAUNCHER_CLASS_NAME));
+    Assert.assertEquals("def1",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.TASK_SCHEDULER_CLASS_NAME));
+    Assert.assertEquals("ghi1",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.TASK_COMMUNICATOR_CLASS_NAME));
   }
 
   @Test(timeout = 5000)
@@ -711,7 +885,10 @@ public class TestHistoryEventTimelineConversion {
 
     VertexStartedEvent event = new VertexStartedEvent(tezVertexID, startRequestedTime, startTime);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
+
     Assert.assertEquals(EntityTypes.TEZ_VERTEX_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezVertexID.toString(), timelineEntity.getEntityId());
 
@@ -738,8 +915,10 @@ public class TestHistoryEventTimelineConversion {
             timelineEntity.getOtherInfo().get(ATSConstants.STATUS));
   }
 
+  @SuppressWarnings("unchecked")
   @Test(timeout = 5000)
   public void testConvertVertexFinishedEvent() {
+    String vertexName = "v1";
     long initRequestedTime = random.nextLong();
     long initedTime = random.nextLong();
     long startRequestedTime = random.nextLong();
@@ -750,11 +929,19 @@ public class TestHistoryEventTimelineConversion {
     taskStats.put("BAR", 200);
     VertexStats vertexStats = new VertexStats();
 
-    VertexFinishedEvent event = new VertexFinishedEvent(tezVertexID, "v1", 1, initRequestedTime,
+    VertexFinishedEvent event = new VertexFinishedEvent(tezVertexID, vertexName, 1, initRequestedTime,
         initedTime, startRequestedTime, startTime, finishTime, VertexState.ERROR,
-        "diagnostics", null, vertexStats, taskStats);
+        "diagnostics", null, vertexStats, taskStats,
+        new ServicePluginInfo().setContainerLauncherName("abc")
+            .setTaskSchedulerName("def").setTaskCommunicatorName("ghi")
+            .setContainerLauncherClassName("abc1")
+            .setTaskSchedulerClassName("def1")
+            .setTaskCommunicatorClassName("ghi1"));
+
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
     Assert.assertEquals(EntityTypes.TEZ_VERTEX_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezVertexID.toString(), timelineEntity.getEntityId());
 
@@ -775,6 +962,8 @@ public class TestHistoryEventTimelineConversion {
     Assert.assertEquals(HistoryEventType.VERTEX_FINISHED.name(), timelineEvent.getEventType());
     Assert.assertEquals(finishTime, timelineEvent.getTimestamp());
 
+    Assert.assertEquals(vertexName,
+        timelineEntity.getOtherInfo().get(ATSConstants.VERTEX_NAME));
     Assert.assertEquals(finishTime,
         ((Long) timelineEntity.getOtherInfo().get(ATSConstants.FINISH_TIME)).longValue());
     Assert.assertEquals(finishTime - startTime,
@@ -783,6 +972,25 @@ public class TestHistoryEventTimelineConversion {
         timelineEntity.getOtherInfo().get(ATSConstants.STATUS));
     Assert.assertEquals("diagnostics",
         timelineEntity.getOtherInfo().get(ATSConstants.DIAGNOSTICS));
+    Assert.assertNotNull(timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN));
+    Assert.assertEquals("abc",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.CONTAINER_LAUNCHER_NAME));
+    Assert.assertEquals("def",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.TASK_SCHEDULER_NAME));
+    Assert.assertEquals("ghi",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.TASK_COMMUNICATOR_NAME));
+    Assert.assertEquals("abc1",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.CONTAINER_LAUNCHER_CLASS_NAME));
+    Assert.assertEquals("def1",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.TASK_SCHEDULER_CLASS_NAME));
+    Assert.assertEquals("ghi1",
+        ((Map<String, Object>)timelineEntity.getOtherInfo().get(ATSConstants.SERVICE_PLUGIN)).get(
+            ATSConstants.TASK_COMMUNICATOR_CLASS_NAME));
 
     Assert.assertTrue(timelineEntity.getOtherInfo().containsKey(ATSConstants.STATS));
 
@@ -798,7 +1006,10 @@ public class TestHistoryEventTimelineConversion {
     long startTime = random.nextLong();
     TaskStartedEvent event = new TaskStartedEvent(tezTaskID, "v1", scheduleTime, startTime);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
+
     Assert.assertEquals(EntityTypes.TEZ_TASK_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezTaskID.toString(), timelineEntity.getEntityId());
 
@@ -842,7 +1053,10 @@ public class TestHistoryEventTimelineConversion {
     TaskAttemptStartedEvent event = new TaskAttemptStartedEvent(tezTaskAttemptID, "v1",
         startTime, containerId, nodeId, "inProgressURL", "logsURL", "nodeHttpAddress");
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
+
     Assert.assertEquals(EntityTypes.TEZ_TASK_ATTEMPT_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezTaskAttemptID.toString(), timelineEntity.getEntityId());
 
@@ -898,7 +1112,9 @@ public class TestHistoryEventTimelineConversion {
 
     TaskFinishedEvent event = new TaskFinishedEvent(tezTaskID, vertexName, startTime, finishTime,
         tezTaskAttemptID, state, diagnostics, counters, 3);
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
 
     Assert.assertEquals(tezTaskID.toString(), timelineEntity.getEntityId());
     Assert.assertEquals(EntityTypes.TEZ_TASK_ID.name(), timelineEntity.getEntityType());
@@ -943,7 +1159,10 @@ public class TestHistoryEventTimelineConversion {
     VertexConfigurationDoneEvent event = new VertexConfigurationDoneEvent(vId, 0L, 1, null,
         edgeMgrs, null, true);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
+
     Assert.assertEquals(ATSConstants.TEZ_VERTEX_ID, timelineEntity.getEntityType());
     Assert.assertEquals(vId.toString(), timelineEntity.getEntityId());
     Assert.assertEquals(1, timelineEntity.getEvents().size());
@@ -981,7 +1200,10 @@ public class TestHistoryEventTimelineConversion {
     DAGRecoveredEvent event = new DAGRecoveredEvent(applicationAttemptId, tezDAGID,
         dagPlan.getName(), user, recoverTime, containerLogs);
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
+
     Assert.assertEquals(EntityTypes.TEZ_DAG_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezDAGID.toString(), timelineEntity.getEntityId());
 
@@ -1017,7 +1239,10 @@ public class TestHistoryEventTimelineConversion {
         dagPlan.getName(), user, recoverTime, DAGState.ERROR, "mock reason", containerLogs);
 
 
-    TimelineEntity timelineEntity = HistoryEventTimelineConversion.convertToTimelineEntity(event);
+    List<TimelineEntity> entities = HistoryEventTimelineConversion.convertToTimelineEntities(event);
+    Assert.assertEquals(1, entities.size());
+    TimelineEntity timelineEntity = entities.get(0);
+
     Assert.assertEquals(EntityTypes.TEZ_DAG_ID.name(), timelineEntity.getEntityType());
     Assert.assertEquals(tezDAGID.toString(), timelineEntity.getEntityId());
 
