@@ -20,7 +20,7 @@ package org.apache.tez.runtime.library.common;
 import org.apache.hadoop.classification.InterfaceAudience.Private;
 
 @Private
-public class Constants {
+public final class Constants {
 
   // TODO NEWTEZ Check which of these constants are expecting specific pieces of information which are being removed - like taskAttemptId
   
@@ -64,4 +64,5 @@ public class Constants {
   public static final String TEZ_RUNTIME_TASK_OUTPUT_MANAGER = 
       "tez.runtime.task.local.output.manager";
 
+  private Constants() {}
 }
