@@ -61,71 +61,71 @@ import org.apache.tez.runtime.library.utils.LocalProgress;
 @InterfaceAudience.Private
 @InterfaceStability.Unstable
 @SuppressWarnings({"unchecked", "rawtypes"})
-public class TezMerger {
+public final class TezMerger {
   private static final Logger LOG = LoggerFactory.getLogger(TezMerger.class);
 
-  
+
   // Local directories
-  private static LocalDirAllocator lDirAlloc = 
+  private static final LocalDirAllocator L_DIR_ALLOC =
     new LocalDirAllocator(TezRuntimeFrameworkConfigs.LOCAL_DIRS);
 
-  public static
-  TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
-                            SerializationContext serializationContext,
-                            CompressionCodec codec, boolean ifileReadAhead,
-                            int ifileReadAheadLength, int ifileBufferSize,
-                            Path[] inputs, boolean deleteInputs, 
-                            int mergeFactor, Path tmpDir,
-                            RawComparator comparator, Progressable reporter,
-                            TezCounter readsCounter,
-                            TezCounter writesCounter,
-                            TezCounter bytesReadCounter,
-                            Progress mergePhase)
-      throws IOException, InterruptedException {
-    return 
-      new MergeQueue(conf, fs, inputs, deleteInputs, codec, ifileReadAhead,
-                           ifileReadAheadLength, ifileBufferSize, false, comparator, 
-                           reporter, null).merge(serializationContext,
-                                           mergeFactor, tmpDir,
-                                           readsCounter, writesCounter,
-                                           bytesReadCounter,
-                                           mergePhase);
+  private TezMerger() {}
+
+  public static TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
+                                             SerializationContext serializationContext,
+                                             CompressionCodec codec, boolean ifileReadAhead,
+                                             int ifileReadAheadLength, int ifileBufferSize,
+                                             Path[] inputs, boolean deleteInputs,
+                                             int mergeFactor, Path tmpDir,
+                                             RawComparator comparator, Progressable reporter,
+                                             TezCounter readsCounter,
+                                             TezCounter writesCounter,
+                                             TezCounter bytesReadCounter,
+                                             Progress mergePhase)
+          throws IOException, InterruptedException {
+    return
+            new MergeQueue(conf, fs, inputs, deleteInputs, codec, ifileReadAhead,
+                    ifileReadAheadLength, ifileBufferSize, false, comparator,
+                    reporter, null).merge(serializationContext,
+                    mergeFactor, tmpDir,
+                    readsCounter, writesCounter,
+                    bytesReadCounter,
+                    mergePhase);
   }
 
   // Used by the in-memory merger.
-  public static
-  TezRawKeyValueIterator merge(Configuration conf, FileSystem fs, 
-                            SerializationContext serializationContext,
-                            List<Segment> segments, 
-                            int mergeFactor, Path tmpDir,
-                            RawComparator comparator, Progressable reporter,
-                            TezCounter readsCounter,
-                            TezCounter writesCounter,
-                            TezCounter bytesReadCounter,
-                            Progress mergePhase)
-      throws IOException, InterruptedException {
+  public static TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
+                                             SerializationContext serializationContext,
+                                             List<Segment> segments,
+                                             int mergeFactor, Path tmpDir,
+                                             RawComparator comparator, Progressable reporter,
+                                             TezCounter readsCounter,
+                                             TezCounter writesCounter,
+                                             TezCounter bytesReadCounter,
+                                             Progress mergePhase)
+          throws IOException, InterruptedException {
     // Get rid of this ?
     return merge(conf, fs, serializationContext, segments, mergeFactor, tmpDir,
-                 comparator, reporter, false, readsCounter, writesCounter, bytesReadCounter,
-                 mergePhase);
+            comparator, reporter, false, readsCounter, writesCounter, bytesReadCounter,
+            mergePhase);
   }
 
-  public static <K extends Object, V extends Object>
+  public static <K, V>
   TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
-                            SerializationContext serializationContext,
-                            List<Segment> segments,
-                            int mergeFactor, Path tmpDir,
-                            RawComparator comparator, Progressable reporter,
-                            boolean sortSegments,
-                            TezCounter readsCounter,
-                            TezCounter writesCounter,
-                            TezCounter bytesReadCounter,
-                            Progress mergePhase)
-      throws IOException, InterruptedException {
+                               SerializationContext serializationContext,
+                               List<Segment> segments,
+                               int mergeFactor, Path tmpDir,
+                               RawComparator comparator, Progressable reporter,
+                               boolean sortSegments,
+                               TezCounter readsCounter,
+                               TezCounter writesCounter,
+                               TezCounter bytesReadCounter,
+                               Progress mergePhase)
+          throws IOException, InterruptedException {
     return new MergeQueue(conf, fs, segments, comparator, reporter,
-                           sortSegments, false).merge(serializationContext, mergeFactor, tmpDir,
-                                               readsCounter, writesCounter,
-                                               bytesReadCounter, mergePhase);
+            sortSegments, false).merge(serializationContext, mergeFactor, tmpDir,
+            readsCounter, writesCounter,
+            bytesReadCounter, mergePhase);
   }
 
   public static TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
@@ -144,97 +144,97 @@ public class TezMerger {
             readsCounter, writesCounter, bytesReadCounter, mergePhase);
   }
 
-  public static <K extends Object, V extends Object>
+  public static <K, V>
   TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
-      SerializationContext serializationContext,
-      CompressionCodec codec,
-      List<Segment> segments,
-      int mergeFactor, Path tmpDir,
-      RawComparator comparator, Progressable reporter,
-      boolean sortSegments,
-      boolean considerFinalMergeForProgress,
-      TezCounter readsCounter,
-      TezCounter writesCounter,
-      TezCounter bytesReadCounter,
-      Progress mergePhase, boolean checkForSameKeys)
-      throws IOException, InterruptedException {
+                               SerializationContext serializationContext,
+                               CompressionCodec codec,
+                               List<Segment> segments,
+                               int mergeFactor, Path tmpDir,
+                               RawComparator comparator, Progressable reporter,
+                               boolean sortSegments,
+                               boolean considerFinalMergeForProgress,
+                               TezCounter readsCounter,
+                               TezCounter writesCounter,
+                               TezCounter bytesReadCounter,
+                               Progress mergePhase, boolean checkForSameKeys)
+          throws IOException, InterruptedException {
     return new MergeQueue(conf, fs, segments, comparator, reporter,
-        sortSegments, codec, considerFinalMergeForProgress, checkForSameKeys).
-        merge(serializationContext,
-            mergeFactor, tmpDir,
+            sortSegments, codec, considerFinalMergeForProgress, checkForSameKeys).
+            merge(serializationContext,
+                    mergeFactor, tmpDir,
+                    readsCounter, writesCounter,
+                    bytesReadCounter,
+                    mergePhase);
+  }
+
+  public static <K, V>
+  TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
+                               SerializationContext serializationContext,
+                               CompressionCodec codec,
+                               List<Segment> segments,
+                               int mergeFactor, Path tmpDir,
+                               RawComparator comparator, Progressable reporter,
+                               boolean sortSegments,
+                               boolean considerFinalMergeForProgress,
+                               TezCounter readsCounter,
+                               TezCounter writesCounter,
+                               TezCounter bytesReadCounter,
+                               Progress mergePhase)
+          throws IOException, InterruptedException {
+    return new MergeQueue(conf, fs, segments, comparator, reporter,
+            sortSegments, codec, considerFinalMergeForProgress).
+            merge(serializationContext, mergeFactor, tmpDir,
+                    readsCounter, writesCounter,
+                    bytesReadCounter,
+                    mergePhase);
+  }
+
+  public static <K, V>
+  TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
+                               SerializationContext serializationContext,
+                               CompressionCodec codec,
+                               List<Segment> segments,
+                               int mergeFactor, int inMemSegments, Path tmpDir,
+                               RawComparator comparator, Progressable reporter,
+                               boolean sortSegments,
+                               TezCounter readsCounter,
+                               TezCounter writesCounter,
+                               TezCounter bytesReadCounter,
+                               Progress mergePhase)
+          throws IOException, InterruptedException {
+    return new MergeQueue(conf, fs, segments, comparator, reporter,
+            sortSegments, codec, false).merge(serializationContext,
+            mergeFactor, inMemSegments,
+            tmpDir,
             readsCounter, writesCounter,
             bytesReadCounter,
             mergePhase);
   }
 
-  public static <K extends Object, V extends Object>
-  TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
-                            SerializationContext serializationContext,
-                            CompressionCodec codec,
-                            List<Segment> segments,
-                            int mergeFactor, Path tmpDir,
-                            RawComparator comparator, Progressable reporter,
-                            boolean sortSegments,
-                            boolean considerFinalMergeForProgress,
-                            TezCounter readsCounter,
-                            TezCounter writesCounter,
-                            TezCounter bytesReadCounter,
-                            Progress mergePhase)
-      throws IOException, InterruptedException {
-    return new MergeQueue(conf, fs, segments, comparator, reporter,
-                           sortSegments, codec, considerFinalMergeForProgress).
-                                         merge(serializationContext, mergeFactor, tmpDir,
-                                             readsCounter, writesCounter,
-                                             bytesReadCounter,
-                                             mergePhase);
-  }
-
-  public static <K extends Object, V extends Object>
-  TezRawKeyValueIterator merge(Configuration conf, FileSystem fs,
-                          SerializationContext serializationContext,
-                          CompressionCodec codec,
-                          List<Segment> segments,
-                          int mergeFactor, int inMemSegments, Path tmpDir,
-                          RawComparator comparator, Progressable reporter,
-                          boolean sortSegments,
-                          TezCounter readsCounter,
-                          TezCounter writesCounter,
-                          TezCounter bytesReadCounter,
-                          Progress mergePhase)
-      throws IOException, InterruptedException {
-  return new MergeQueue(conf, fs, segments, comparator, reporter,
-                         sortSegments, codec, false).merge(serializationContext,
-                                             mergeFactor, inMemSegments,
-                                             tmpDir,
-                                             readsCounter, writesCounter,
-                                             bytesReadCounter,
-                                             mergePhase);
-}
-
-  public static <K extends Object, V extends Object>
+  public static <K, V>
   void writeFile(TezRawKeyValueIterator records, Writer writer,
-      Progressable progressable, long recordsBeforeProgress)
-      throws IOException, InterruptedException {
+                 Progressable progressable, long recordsBeforeProgress)
+          throws IOException, InterruptedException {
     long recordCtr = 0;
     long count = 0;
-    while(records.next()) {
+    while (records.next()) {
       if (records.isSameKey()) {
         writer.append(IFile.REPEAT_KEY, records.getValue());
         count++;
       } else {
         writer.append(records.getKey(), records.getValue());
       }
-      
+
       if (((recordCtr++) % recordsBeforeProgress) == 0) {
         progressable.progress();
         if (Thread.currentThread().isInterrupted()) {
-          /**
+          /*
            * Takes care DefaultSorter.mergeParts, MergeManager's merger threads,
            * PipelinedSorter's flush(). This is not expensive check as it is carried out every
            * 10000 records or so.
            */
           throw new InterruptedException("Current thread=" + Thread.currentThread().getName() + " got "
-              + "interrupted");
+                  + "interrupted");
         }
       }
     }
@@ -250,7 +250,7 @@ public class TezMerger {
     private int position;
     private int length;
 
-    public KeyValueBuffer(byte buf[], int position, int length) {
+    KeyValueBuffer(byte[] buf, int position, int length) {
       reset(buf, position, length);
     }
 
@@ -279,7 +279,7 @@ public class TezMerger {
     static final byte[] EMPTY_BYTES = new byte[0];
     Reader reader = null;
     final KeyValueBuffer key = new KeyValueBuffer(EMPTY_BYTES, 0, 0);
-    TezCounter mapOutputsCounter = null;
+    private TezCounter mapOutputsCounter;
 
     public Segment(Reader reader, TezCounter mapOutputsCounter) {
       this.reader = reader;
@@ -358,15 +358,17 @@ public class TezMerger {
   @InterfaceStability.Unstable
   public static class DiskSegment extends Segment {
 
-    FileSystem fs = null;
-    Path file = null;
-    boolean preserve = false; // Signifies whether the segment should be kept after a merge is complete. Checked in the close method.
-    CompressionCodec codec = null;
-    long segmentOffset = 0;
-    long segmentLength = -1;
+    private FileSystem fs;
+    private Path file;
+
+    // Signifies whether the segment should be kept after a merge is complete. Checked in the close method.
+    private boolean preserve;
+    private CompressionCodec codec;
+    private long segmentOffset;
+    private long segmentLength;
     boolean ifileReadAhead;
     int ifileReadAheadLength;
-    int bufferSize = -1;
+    private int bufferSize;
 
     public DiskSegment(FileSystem fs, Path file,
         CompressionCodec codec, boolean ifileReadAhead,
@@ -377,19 +379,19 @@ public class TezMerger {
     }
 
     public DiskSegment(FileSystem fs, Path file,
-                   CompressionCodec codec, boolean ifileReadAhead, int ifileReadAheadLenth,
+                   CompressionCodec codec, boolean ifileReadAhead, int ifileReadAheadLength,
                    int bufferSize, boolean preserve, TezCounter mergedMapOutputsCounter)
   throws IOException {
       this(fs, file, 0, fs.getFileStatus(file).getLen(), codec,
-          ifileReadAhead, ifileReadAheadLenth, bufferSize, preserve,
+          ifileReadAhead, ifileReadAheadLength, bufferSize, preserve,
           mergedMapOutputsCounter);
     }
 
     public DiskSegment(FileSystem fs, Path file,
                    long segmentOffset, long segmentLength,
                    CompressionCodec codec, boolean ifileReadAhead,
-                   int ifileReadAheadLength,  int bufferSize, 
-                   boolean preserve) throws IOException {
+                   int ifileReadAheadLength,  int bufferSize,
+                   boolean preserve) {
       this(fs, file, segmentOffset, segmentLength, codec, ifileReadAhead,
           ifileReadAheadLength, bufferSize, preserve, null);
     }
@@ -397,8 +399,7 @@ public class TezMerger {
     public DiskSegment(FileSystem fs, Path file,
         long segmentOffset, long segmentLength, CompressionCodec codec,
         boolean ifileReadAhead, int ifileReadAheadLength, int bufferSize,
-        boolean preserve, TezCounter mergedMapOutputsCounter)
-    throws IOException {
+        boolean preserve, TezCounter mergedMapOutputsCounter) {
       super(null, mergedMapOutputsCounter);
       this.fs = fs;
       this.file = file;
@@ -460,7 +461,7 @@ public class TezMerger {
   }
 
   @VisibleForTesting
-  static class MergeQueue<K extends Object, V extends Object>
+  static class MergeQueue<K, V>
   extends PriorityQueue<Segment> implements TezRawKeyValueIterator {
     final Configuration conf;
     final FileSystem fs;
@@ -470,9 +471,9 @@ public class TezMerger {
     static final int ifileReadAheadLength = TezRuntimeConfiguration.TEZ_RUNTIME_IFILE_READAHEAD_BYTES_DEFAULT;
     static final int ifileBufferSize = TezRuntimeConfiguration.TEZ_RUNTIME_IFILE_BUFFER_SIZE_DEFAULT;
     static final long recordsBeforeProgress = TezRuntimeConfiguration.TEZ_RUNTIME_RECORDS_BEFORE_PROGRESS_DEFAULT;
-    
-    List<Segment> segments = new ArrayList<Segment>();
-    
+
+    private List<Segment> segments = new ArrayList<>();
+
     final RawComparator comparator;
 
     private long totalBytesProcessed;
@@ -484,14 +485,14 @@ public class TezMerger {
     private final boolean considerFinalMergeForProgress;
 
     final Progressable reporter;
-    
+
     final DataInputBuffer key = new DataInputBuffer();
     final DataInputBuffer value = new DataInputBuffer();
     final DataInputBuffer nextKey = new DataInputBuffer();
     final DataInputBuffer diskIFileValue = new DataInputBuffer();
-    
+
     Segment minSegment;
-    Comparator<Segment> segmentComparator =   
+    Comparator<Segment> segmentComparator =
       new Comparator<Segment>() {
       public int compare(Segment o1, Segment o2) {
         if (o1.getLength() == o2.getLength()) {
@@ -505,13 +506,13 @@ public class TezMerger {
     KeyState hasNext;
     DataOutputBuffer prevKey = new DataOutputBuffer();
 
-    public MergeQueue(Configuration conf, FileSystem fs, 
+    public MergeQueue(Configuration conf, FileSystem fs,
                       Path[] inputs, boolean deleteInputs,
                       CompressionCodec codec, boolean ifileReadAhead,
                       int ifileReadAheadLength, int ifileBufferSize,
                       boolean considerFinalMergeForProgress,
-                      RawComparator comparator, Progressable reporter, 
-                      TezCounter mergedMapOutputsCounter) 
+                      RawComparator comparator, Progressable reporter,
+                      TezCounter mergedMapOutputsCounter)
     throws IOException {
       this.conf = conf;
       this.checkForSameKeys = true;
@@ -523,23 +524,23 @@ public class TezMerger {
       this.comparator = comparator;
       this.reporter = reporter;
       this.considerFinalMergeForProgress = considerFinalMergeForProgress;
-      
+
       for (Path file : inputs) {
         if (LOG.isTraceEnabled()) {
           LOG.trace("MergeQ: adding: " + file);
         }
         segments.add(new DiskSegment(fs, file, codec, ifileReadAhead,
                                       ifileReadAheadLength, ifileBufferSize,
-                                      !deleteInputs, 
+                                      !deleteInputs,
                                        (file.toString().endsWith(
-                                           Constants.MERGED_OUTPUT_PREFIX) ? 
+                                           Constants.MERGED_OUTPUT_PREFIX) ?
                                         null : mergedMapOutputsCounter)));
       }
-      
+
       // Sort segments on file-lengths
-      Collections.sort(segments, segmentComparator); 
+      segments.sort(segmentComparator);
     }
-    
+
     public MergeQueue(Configuration conf, FileSystem fs,
         List<Segment> segments, RawComparator comparator,
         Progressable reporter, boolean sortSegments, boolean considerFinalMergeForProgress) {
@@ -566,7 +567,7 @@ public class TezMerger {
       this.reporter = reporter;
       this.considerFinalMergeForProgress = considerFinalMergeForProgress;
       if (sortSegments) {
-        Collections.sort(segments, segmentComparator);
+        segments.sort(segmentComparator);
       }
       this.checkForSameKeys = checkForSameKeys;
       this.codec = codec;
@@ -596,7 +597,7 @@ public class TezMerger {
       long startPos = reader.getPosition();
       if (checkForSameKeys) {
         if (hasNext == null) {
-          /**
+          /*
            * hasNext can be null during first iteration & prevKey is initialized here.
            * In cases of NO_KEY/NEW_KEY, we readjust the queue later. If new segment/file is found
            * during this process, we need to compare keys for RLE across segment boundaries.
@@ -606,7 +607,7 @@ public class TezMerger {
         } else {
           //indicates a key has been read already
           if (hasNext != KeyState.SAME_KEY) {
-            /**
+            /*
              * Store previous key before reading next for later key comparisons.
              * If all keys in a segment are unique, it would always hit this code path and key copies
              * are wasteful in such condition, as these comparisons are mainly done for RLE.
@@ -635,9 +636,6 @@ public class TezMerger {
     /**
      * Check if the previous key is same as the next top segment's key.
      * This would be useful to compute whether same key is spread across multiple segments.
-     *
-     * @param current
-     * @throws IOException
      */
     void compareKeyWithNextTopKey(Segment current) throws IOException {
       Segment nextTop = top();
@@ -668,7 +666,7 @@ public class TezMerger {
         //the same byte[] since it would corrupt the data in the inmem
         //segment. So we maintain an explicit DIB for value bytes
         //obtained from disk, and if the current segment is a disk
-        //segment, we reset the "value" DIB to the byte[] in that (so 
+        //segment, we reset the "value" DIB to the byte[] in that (so
         //we reuse the disk segment DIB whenever we consider
         //a disk segment).
         minSegment.getValue(diskIFileValue);
@@ -699,11 +697,11 @@ public class TezMerger {
       int s1 = key1.getPosition();
       int l1 = key1.getLength();
       int s2 = key2.getPosition();
-      int l2 = key2.getLength();;
+      int l2 = key2.getLength();
 
       return comparator.compare(key1.getData(), s1, l1, key2.getData(), s2, l2) < 0;
     }
-    
+
     public TezRawKeyValueIterator merge(SerializationContext serializationContext,
                                         int factor, Path tmpDir,
                                         TezCounter readsCounter,
@@ -747,7 +745,7 @@ public class TezMerger {
       if (totalBytes != 0) {
         progPerByte = 1.0f / (float)totalBytes;
       }
-      
+
       //create the MergeStreams from the sorted map created in the constructor
       //and dump the final output to a file
       do {
@@ -759,14 +757,14 @@ public class TezMerger {
           factor += inMem;
         }
         List<Segment> segmentsToMerge =
-          new ArrayList<Segment>();
+                new ArrayList<>();
         int segmentsConsidered = 0;
         int numSegmentsToConsider = factor;
         long startBytes = 0; // starting bytes of segments of this merge
         while (true) {
-          //extract the smallest 'factor' number of segments  
+          //extract the smallest 'factor' number of segments
           //Call cleanup on the empty segments (no key/value data)
-          List<Segment> mStream = 
+          List<Segment> mStream =
             getSegmentDescriptors(numSegmentsToConsider);
           for (Segment segment : mStream) {
             // Initialize the segment at the last possible moment;
@@ -776,7 +774,7 @@ public class TezMerger {
             long startPos = segment.getPosition();
             boolean hasNext = segment.nextRawKey(nextKey);
             long endPos = segment.getPosition();
-            
+
             if (hasNext) {
               startBytes += endPos - startPos;
               segmentsToMerge.add(segment);
@@ -789,7 +787,7 @@ public class TezMerger {
           }
           //if we have the desired number of segments
           //or looked at all available segments, we break
-          if (segmentsConsidered == factor || 
+          if (segmentsConsidered == factor ||
               segments.size() == 0) {
             break;
           }
@@ -797,14 +795,14 @@ public class TezMerger {
           // Get the correct # of segments in case some of them were empty.
           numSegmentsToConsider = factor - segmentsConsidered;
         }
-        
+
         //feed the streams to the priority queue
         initialize(segmentsToMerge.size());
         clear();
         for (Segment segment : segmentsToMerge) {
           put(segment);
         }
-        
+
         //if we have lesser number of segments remaining, then just return the
         //iterator, else do another single level merge
         if (numSegments <= factor) { // Will always kick in if only in-mem segments are provided.
@@ -816,13 +814,13 @@ public class TezMerger {
             // the 3rd phase of reduce task.
             totalBytesProcessed = 0;
             totalBytes = 0;
-            for (int i = 0; i < segmentsToMerge.size(); i++) {
-              totalBytes += segmentsToMerge.get(i).getLength();
+            for (Segment segment : segmentsToMerge) {
+              totalBytes += segment.getLength();
             }
           }
           if (totalBytes != 0) //being paranoid
             progPerByte = 1.0f / (float)totalBytes;
-          
+
           totalBytesProcessed += startBytes;
           if (totalBytes != 0)
             mergeProgress.set(totalBytesProcessed * progPerByte);
@@ -845,22 +843,22 @@ public class TezMerger {
                 " intermediate segments out of a total of " +
                 (segments.size() + segmentsToMerge.size()));
           }
-          
+
           long bytesProcessedInPrevMerges = totalBytesProcessed;
           totalBytesProcessed += startBytes;
 
-          //we want to spread the creation of temp files on multiple disks if 
+          //we want to spread the creation of temp files on multiple disks if
           //available under the space constraints
-          long approxOutputSize = 0; 
+          long approxOutputSize = 0;
           for (Segment s : segmentsToMerge) {
-            approxOutputSize += s.getLength() + 
+            approxOutputSize += s.getLength() +
                                 ChecksumFileSystem.getApproxChkSumLength(
                                 s.getLength());
           }
-          Path tmpFilename = 
+          Path tmpFilename =
             new Path(tmpDir, "intermediate").suffix("." + passNo);
 
-          Path outputFile =  lDirAlloc.getLocalPathForWrite(
+          Path outputFile =  L_DIR_ALLOC.getLocalPathForWrite(
                                               tmpFilename.toString(),
                                               approxOutputSize, conf);
 
@@ -873,13 +871,13 @@ public class TezMerger {
 
           writeFile(this, writer, reporter, recordsBeforeProgress);
           writer.close();
-          
-          //we finished one single level merge; now clean up the priority 
+
+          //we finished one single level merge; now clean up the priority
           //queue
           this.close();
 
           // Add the newly create segment to the list of segments to be merged
-          Segment tempSegment = 
+          Segment tempSegment =
             new DiskSegment(fs, outputFile, codec, ifileReadAhead,
                 ifileReadAheadLength, ifileBufferSize, false);
 
@@ -892,8 +890,8 @@ public class TezMerger {
           }
           segments.add(pos, tempSegment);
           numSegments = segments.size();
-          
-          // Subtract the difference between expected size of new segment and 
+
+          // Subtract the difference between expected size of new segment and
           // actual size of new segment(Expected size of new segment is
           // inputBytesOfThisMerge) from totalBytes. Expected size and actual
           // size will match(almost) if combiner is not called in merge.
@@ -903,15 +901,15 @@ public class TezMerger {
           if (totalBytes != 0) {
             progPerByte = 1.0f / (float)totalBytes;
           }
-          
+
           passNo++;
         }
-        //we are worried about only the first pass merge factor. So reset the 
+        //we are worried about only the first pass merge factor. So reset the
         //factor to what it originally was
         factor = origFactor;
       } while(true);
     }
-    
+
     /**
      * Determine the number of segments to merge in a given pass. Assuming more
      * than factor segments, the first pass should attempt to bring the total
@@ -920,20 +918,22 @@ public class TezMerger {
      */
     private static int getPassFactor(int factor, int passNo, int numSegments) {
       // passNo > 1 in the OR list - is that correct ?
-      if (passNo > 1 || numSegments <= factor || factor == 1) 
+      if (passNo > 1 || numSegments <= factor || factor == 1) {
         return factor;
+      }
       int mod = (numSegments - 1) % (factor - 1);
-      if (mod == 0)
+      if (mod == 0) {
         return factor;
+      }
       return mod + 1;
     }
-    
+
     /** Return (& remove) the requested number of segment descriptors from the
      * sorted map.
      */
     private List<Segment> getSegmentDescriptors(int numDescriptors) {
       if (numDescriptors > segments.size()) {
-        List<Segment> subList = new ArrayList<Segment>(segments);
+        List<Segment> subList = new ArrayList<>(segments);
         segments.clear();
         return subList;
       }
@@ -944,7 +944,7 @@ public class TezMerger {
       subList.clear();
       return subListCopy;
     }
-    
+
     /**
      * Compute expected size of input bytes to merges, will be used in
      * calculating mergeProgress. This simulates the above merge() method and
@@ -963,13 +963,13 @@ public class TezMerger {
       // factor for 1st pass
       int f = getPassFactor(factor, 1, n) + inMem;
       n = numSegments;
- 
+
       for (int i = 0; i < numSegments; i++) {
         // Not handling empty segments here assuming that it would not affect
         // much in calculation of mergeProgress.
         segmentSizes[i] = segments.get(i).getLength();
       }
-      
+
       // If includeFinalMerge is true, allow the following while loop iterate
       // for 1 more iteration. This is to include final merge as part of the
       // computation of expected input bytes of merges
@@ -986,7 +986,7 @@ public class TezMerger {
           mergedSize += segmentSizes[offset + j];
         }
         totalBytes += mergedSize;
-        
+
         // insert new size into the sorted list
         int pos = Arrays.binarySearch(segmentSizes, offset, offset + n, mergedSize);
         if (pos < 0) {
