@@ -23,6 +23,7 @@ import org.apache.hadoop.fs.FSDataOutputStream;
 import org.apache.hadoop.fs.FileSystem;
 import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.Text;
+import org.apache.hadoop.io.serializer.WritableSerialization;
 import org.apache.tez.common.counters.TaskCounter;
 import org.apache.tez.common.counters.TezCounter;
 import org.apache.tez.common.counters.TezCounters;
@@ -131,8 +132,8 @@ public class TestUnorderedKVReader {
 
   private void createIFile(Path path, int recordCount) throws IOException {
     FSDataOutputStream out = localFs.create(path);
-    IFile.Writer writer =
-        new IFile.Writer(defaultConf, out, Text.class, Text.class, null, null, null, true);
+    IFile.Writer writer = new IFile.Writer(new WritableSerialization(), new WritableSerialization(),
+        out, Text.class, Text.class, null, null, null, true);
 
     for (int i = 0; i < recordCount; i++) {
       writer.append(new Text("Key_" + i), new Text("Value_" + i));
