@@ -386,7 +386,7 @@ public class TestIFile {
   // bytes between segments. If the lingering bytes aren't handled correctly,
   // the stream will get out-of-sync.
   @Test(timeout = 5000)
-  @org.junit.Ignore public void testConcatenatedZlibPadding()
+  public void testConcatenatedZlibPadding()
       throws IOException, URISyntaxException {
     byte[] bytes;
     long compTotal = 0;
