@@ -26,8 +26,8 @@ import org.junit.Assert;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
-import static org.mockito.Matchers.any;
-import static org.mockito.Matchers.anyLong;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.anyLong;
 import static org.mockito.Mockito.atLeastOnce;
 import static org.mockito.Mockito.doAnswer;
 import static org.mockito.Mockito.doReturn;
@@ -52,7 +52,6 @@ import org.apache.hadoop.fs.Path;
 import org.apache.hadoop.io.DataOutputBuffer;
 import org.apache.hadoop.io.NullWritable;
 import org.apache.hadoop.io.Text;
-import org.apache.hadoop.util.StringInterner;
 import org.apache.tez.common.TezRuntimeFrameworkConfigs;
 import org.apache.tez.common.TezUtils;
 import org.apache.tez.common.counters.TaskCounter;
@@ -64,7 +63,6 @@ import org.apache.tez.dag.api.TezConfiguration;
 import org.apache.tez.dag.api.UserPayload;
 import org.apache.tez.runtime.api.Event;
 import org.apache.tez.runtime.api.ExecutionContext;
-import org.apache.tez.runtime.api.MemoryUpdateCallback;
 import org.apache.tez.runtime.api.OutputContext;
 import org.apache.tez.runtime.api.OutputStatisticsReporter;
 import org.apache.tez.runtime.api.events.CompositeDataMovementEvent;
@@ -78,6 +76,7 @@ import org.apache.tez.runtime.library.common.sort.impl.TezSpillRecord;
 import org.apache.tez.runtime.library.conf.OrderedPartitionedKVOutputConfig.SorterImpl;
 import org.apache.tez.runtime.library.partitioner.HashPartitioner;
 import org.apache.tez.runtime.library.shuffle.impl.ShuffleUserPayloads;
+import org.apache.tez.util.StringInterner;
 import org.junit.After;
 import org.junit.AfterClass;
 import org.junit.Before;
@@ -222,7 +221,7 @@ public class TestDefaultSorter {
       Text key = new Text(i + "");
       //Generate random size between 1 MB to 100 MB.
       int valSize = ThreadLocalRandom.current().nextInt(1 * 1024 * 1024, 100 * 1024 * 1024);
-      String val = StringInterner.weakIntern(StringUtils.repeat("v", valSize));
+      String val = StringInterner.intern(StringUtils.repeat("v", valSize));
       sorter.write(key, new Text(val));
       i = (i + 1) % 10;
     }
@@ -703,7 +702,7 @@ public class TestDefaultSorter {
         callback.memoryAssigned(requestedSize);
         return null;
       }
-    }).when(context).requestInitialMemory(anyLong(), any(MemoryUpdateCallback.class));
+    }).when(context).requestInitialMemory(anyLong(), any());
     return context;
   }
-}
\ No newline at end of file
+}
