@@ -64,13 +64,14 @@ module.exports = function(defaults) {
 
   app.import('bower_components/more-js/dist/more.js');
 
-  app.import('bower_components/file-saver.js/FileSaver.js');
+  app.import('bower_components/file-saver/FileSaver.js');
   app.import('bower_components/zip-js/WebContent/zip.js');
 
   app.import('bower_components/codemirror/lib/codemirror.js');
   app.import('bower_components/codemirror/mode/sql/sql.js');
   app.import('bower_components/codemirror/mode/pig/pig.js');
   app.import('bower_components/codemirror/lib/codemirror.css');
+  app.import('bower_components/alasql/dist/alasql.js');
 
   return app.toTree(new MergeTrees([configEnv, zipWorker, copyFonts]));
 };
